==> nextcloud-21.0.0p0.tgz: nextcloud/apps/accessibility/l10n/zh_HK.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "黑暗主題",
    "Enable dark theme" : "使用黑暗主題",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "黑暗主題將降低整體光度與亮度，以舒緩眼睛疲勞。此功能仍在發展當中，請報告任何您遇上的問題。",
    "High contrast mode" : "高對比模式",
    "Enable high contrast mode" : "使用高對比模式",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "高對比模式能使您的瀏覽更容易。視覺品質將被降低，但清晰度將被提高。",
    "Dyslexia font" : "閱讀困難症字體",
    "Enable dyslexia font" : "啟用閱讀困難症字型",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic 是一種免費的字型，目的在降低因拼音文字閱讀困難引起的一些常見閱讀錯誤。",
    "Accessibility" : "輔助工具",
    "Accessibility options for nextcloud" : " Nextcloud 輔助工具設定",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "提供多種 輔助工具使您更易於操作 Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "我們非常重視無障礙存取。我們遵循網路標準，並透過檢查來確保所有內容皆可在沒有滑鼠或輔助軟體（例如螢幕閱讀器）的情況下使用。我們目標是能達到 {guidelines}網頁內容可及性指引{linkend} 2.1 版的 AA 等級，加上高對比度主題甚至還能到 AAA 等級。",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : " \n如果您發現任何一個問題，請不要猶豫並請在 {issuetracker}我們的問題追蹤系統{linkend} 回報。而如果您想參與，歡迎加入 {designteam}我們的設計團隊{linked}！"
},
"nplurals=1; plural=0;");

==> nextcloud-21.0.8p0.tgz: nextcloud/apps/accessibility/l10n/zh_HK.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "黑暗主題",
    "Enable dark theme" : "使用黑暗主題",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "黑暗主題將降低整體光度與亮度，以舒緩眼睛疲勞。此功能仍在發展當中，請報告任何您遇上的問題。",
    "High contrast mode" : "高對比模式",
    "Enable high contrast mode" : "使用高對比模式",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "高對比模式能使您的瀏覽更容易。視覺品質將被降低，但清晰度將被提高。",
    "Dyslexia font" : "閱讀困難症字體",
    "Enable dyslexia font" : "啟用閱讀困難症字型",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic 是一種免費的字型，目的在降低因拼音文字閱讀困難引起的一些常見閱讀錯誤。",
    "Accessibility" : "輔助工具",
    "Accessibility options for nextcloud" : "Nextcloud 輔助工具設定",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "提供多種 輔助工具使您更易於操作 Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "我們非常重視無障礙存取。我們遵循網路標準，並透過檢查來確保所有內容皆可在沒有滑鼠或輔助軟體（例如螢幕閱讀器）的情況下使用。我們目標是能達到 {guidelines}網頁內容可及性指引{linkend} 2.1 版的 AA 等級，加上高對比度主題甚至還能到 AAA 等級。",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : " \n如果您發現任何一個問題，請不要猶豫並請在 {issuetracker}我們的問題追蹤系統{linkend} 舉報。而如果您想參與，歡迎加入 {designteam}我們的設計團隊{linked}！"
},
"nplurals=1; plural=0;");
